eprllib.ActionFunctions.ActionFunctions — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.ActionFunctions.ActionFunctions

## Action Function Base Class

This module contain the base class to create action transformer functions. Action transformer functions are used to transform the actions of the agents. They are used in the EnvConfig class to create the environment.

Classes

`ActionFunction`([action_fn_config]) | Base class to create action transformer functions.